@@ -1,4 +1,4 @@
-use std::ops::{Deref, DerefMut};
+use std::ops::{Deref};
 
 impl<Data> Observable<Data> {
     pub fn new(value: Data) -> Observable<Data> {
@@ -41,3 +41,12 @@ impl<Data> Deref for Observable<Data> {
         &self.data
     }
 }
+
+impl<Data: Default> Default for Observable<Data> {
+    fn default() -> Self {
+        Observable{
+            data: Data::default(),
+            listeners: Vec::new(),
+        }
+    }
+}
\ No newline at end of file
